.. _spkg_referencing:

referencing: JSON Referencing + Python
======================================

Description
-----------

JSON Referencing + Python

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/referencing/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_attrs`
- :ref:`spkg_pip`
- :ref:`spkg_rpds_py`

Version Information
-------------------

package-version.txt::

    0.35.1

version_requirements.txt::

    referencing

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install referencing

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i referencing

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-referencing


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
